@@ -80,7 +80,12 @@ class PluginManager:
         """Load plugins from the given directory. Returns False if the dir does not exist.
         """
         dirname = os.path.dirname(__file__)
-        dir_path = os.path.join(dirname, '..\\', load_dir)
+        if os.name == 'nt': #windows
+            dir_path = os.path.join(dirname, '..\\', load_dir)
+        else:
+            dir_path = os.path.join(dirname, '../', load_dir)
+
+        self.plugin_dir = dir_path
         if not os.path.exists(dir_path):
             return False
 
@@ -136,7 +141,7 @@ class PluginManager:
         logging.getLogger('plugin').info("Found {} valid plugins in '{}'. Loading plugins...".format(
             len(plugin_classes), dir_path))
 
-        self.plugin_dir = dir_path
+        #self.plugin_dir = dir_path
 
         self.plugins = list()
         for cls in plugin_classes:
@@ -268,7 +273,10 @@ class PluginDialog(wx.Dialog):
         super().__init__(parent, title='Manage Plugins', size=(900, 550))
         notebook = wx.Listbook(self, style=wx.LB_LEFT)
         notebook.GetListView().SetFont(wx.Font(wx.FontInfo(10)))
-        notebook.GetListView().SetColumnWidth(0, 125)
+        try:
+            notebook.GetListView().SetColumnWidth(0, 125)
+        except:
+            pass
 
         sizer = wx.BoxSizer()
         sizer.Add(notebook, proportion=1, flag=wx.EXPAND)
@@ -307,7 +315,10 @@ class PluginInstallationDialog(wx.Dialog):
         super().__init__(parent, title='Add Plugins', size=(900, 550))
         notebook = wx.Listbook(self, style=wx.LB_LEFT)
         notebook.GetListView().SetFont(wx.Font(wx.FontInfo(10)))
-        notebook.GetListView().SetColumnWidth(0, 125)
+        try:
+            notebook.GetListView().SetColumnWidth(0, 125)
+        except:
+            pass
 
         sizer = wx.BoxSizer()
         sizer.Add(notebook, proportion=1, flag=wx.EXPAND)
